@@ -1,6 +1,6 @@
 package MojoX::Renderer::TT;
 BEGIN {
-  $MojoX::Renderer::TT::VERSION = '1.11';
+  $MojoX::Renderer::TT::VERSION = '1.13';
 }
 
 use warnings;
@@ -153,14 +153,16 @@ sub _template_content {
     my $self = shift;
     my ($path) = @_;
 
-    my ($t) = ($path =~ m{templates[\/|\\](.*)$});
+    # Convert backslashes to forward slashes to make inline templates work on Windows
+    $path =~ s/\\/\//g;
+    my ($t) = ($path =~ m{templates\/(.*)$});
 
     if (-r $path) {
         return $self->SUPER::_template_content(@_);
     }
 
     # Try DATA section
-    elsif (my $d = $self->renderer->get_inline_template($self->ctx, $t)) {
+    elsif (my $d = $self->renderer->get_data_template($self->ctx, $t)) {
         return wantarray ? ($d, '', time) : $d;
     }
 
